==> ejc-outcontract-impl-3.0.0-20220808.015611-93-sources.jar: com/ejianc/foundation/outcontract/bean/ChangeOutcontractSupplementaryAgreementEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 变更补充协议
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_outcontract_supplementary_agreement")
public class ChangeOutcontractSupplementaryAgreementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="supplementary_content")
    private String supplementaryContent; // 补充内容
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public String getSupplementaryContent() {
        return supplementaryContent;
    }

    public void setSupplementaryContent(String supplementaryContent) {
        this.supplementaryContent = supplementaryContent;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20250107.020835-237-sources.jar: com/ejianc/foundation/outcontract/bean/ChangeOutcontractSupplementaryAgreementEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 变更补充协议
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_outcontract_supplementary_agreement")
public class ChangeOutcontractSupplementaryAgreementEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="supplementary_content")
    private String supplementaryContent; // 补充内容
    @TableField(value="remark")
    private String remark; // 备注
    
    @TableField(value="change_amount")
    private BigDecimal changeAmount; // 变更金额
    @TableField(value="supplementary_sign_time")
    private Date supplementarySignTime; // 签约时间
    @TableField(value="this_change")
    private String thisChange; // 是否本次变更数据（1：是）

    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public String getSupplementaryContent() {
        return supplementaryContent;
    }

    public void setSupplementaryContent(String supplementaryContent) {
        this.supplementaryContent = supplementaryContent;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public BigDecimal getChangeAmount() {
		return changeAmount;
	}

	public void setChangeAmount(BigDecimal changeAmount) {
		this.changeAmount = changeAmount;
	}

	public Date getSupplementarySignTime() {
		return supplementarySignTime;
	}

	public void setSupplementarySignTime(Date supplementarySignTime) {
		this.supplementarySignTime = supplementarySignTime;
	}

	public String getThisChange() {
		return thisChange;
	}

	public void setThisChange(String thisChange) {
		this.thisChange = thisChange;
	}
    
}
